@@ -3,18 +3,8 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from asyncio import set_event_loop_policy, AbstractEventLoopPolicy
-from .base import ArgsType, CoroOrFunction, KwargsType, IRunner
-from .arunner import AsyncRunner
-
-
-def set_loop_policy(policy: AbstractEventLoopPolicy = None):
-    if policy is None:
-        return
-    try:
-        set_event_loop_policy(policy)
-    except Exception as e:
-        raise e
+from .runner.base import ArgsType, CoroOrFunction, KwargsType, IRunner
+from .runner import AsyncRunner
 
 
 def is_runner(value):
